@@ -2,7 +2,6 @@ from __future__ import annotations
 
 import ast
 import keyword
-import sys
 from typing import NamedTuple
 from typing import Sequence
 
@@ -64,28 +63,11 @@ def find_end(tokens: list[Token], i: int) -> int:
     return i
 
 
-if sys.version_info >= (3, 8):  # pragma: >=3.8 cover
-    # python 3.8 fixed the offsets of generators / tuples
-    def _arg_token_index(tokens: list[Token], i: int, arg: ast.expr) -> int:
-        idx = _search_until(tokens, i, arg) + 1
-        while idx < len(tokens) and tokens[idx].name in NON_CODING_TOKENS:
-            idx += 1
-        return idx
-else:  # pragma: <3.8 cover
-    def _arg_token_index(tokens: list[Token], i: int, arg: ast.expr) -> int:
-        # lists containing non-tuples report the first element correctly
-        if isinstance(arg, ast.List):
-            # If the first element is a tuple, the ast lies to us about its col
-            # offset.  We must find the first `(` token after the start of the
-            # list element.
-            if isinstance(arg.elts[0], ast.Tuple):
-                i = _search_until(tokens, i, arg)
-                return find_open_paren(tokens, i)
-            else:
-                return _search_until(tokens, i, arg.elts[0])
-            # others' start position points at their first child node already
-        else:
-            return _search_until(tokens, i, arg)
+def _arg_token_index(tokens: list[Token], i: int, arg: ast.expr) -> int:
+    idx = _search_until(tokens, i, arg) + 1
+    while idx < len(tokens) and tokens[idx].name in NON_CODING_TOKENS:
+        idx += 1
+    return idx
 
 
 def victims(
@@ -499,17 +481,6 @@ def replace_argument(
     tokens[start_idx:end_idx] = [Token('SRC', new)]
 
 
-def find_comprehension_opening_bracket(i: int, tokens: list[Token]) -> int:
-    """Find opening bracket of comprehension given first argument."""
-    if sys.version_info < (3, 8):  # pragma: <3.8 cover
-        i -= 1
-        while not (tokens[i].name == 'OP' and tokens[i].src == '[') and i:
-            i -= 1
-        return i
-    else:  # pragma: >=3.8 cover
-        return i
-
-
 def has_space_before(i: int, tokens: list[Token]) -> bool:
     return i >= 1 and tokens[i - 1].name in {UNIMPORTANT_WS, 'INDENT'}
 
